
'Cognite API SDK\n\nThis package has been created to ensure excellent excellent user experience for data scientists using the Cognite\nData Platform (CDP).\n'
__all__ = ['assets', 'config', 'data_objects', 'tagmatching', 'timeseries', 'raw', 'preprocessing']
__version__ = '0.4.35'
